@@ -52,7 +52,7 @@ class gitricsGroup(GitlabGroup):
         self.issues = issues if issues else gitricsItemSet("issues")
 
         # get users
-        self.users = self.extract_users()
+        self.users = users if users else self.extract_users()
 
     def determine_most_at_risk(self, items: list) -> list:
         """
@@ -103,18 +103,24 @@ class gitricsGroup(GitlabGroup):
         ids = list()
         subitem = getattr(item, item.gitlab_type)
 
-        # check for notes
-        if item.notes:
-
-            # assign ownership by participation
-            ids = [x[0] for x in Counter(d["author"]["id"] for d in item.notes).most_common(3)]
-
         # check for assignees
         if "assignees" in subitem and subitem["assignees"]:
 
             # add as assignees
             ids = [d["id"] for d in subitem["assignees"]]
 
+        # check for notes
+        elif item.notes:
+
+            # assign ownership by participation
+            ids = [x[0] for x in Counter(d["author"]["id"] for d in item.notes).most_common(3)]
+
+        # check for participants
+        elif item.participants:
+
+            # because we can't determine level of participation list all
+            ids = [d["id"] for d in item.participants]
+
         # replace ids with full user objects
         result = [d for d in self.users if d.id in ids] if self.users else list()
 
